import '../../pages/makeup/entry/entry'
const page = global.wxPageInstance

describe('page life cycle', () => {
  beforeAll(() => {
    jest.spyOn(page, 'handleConfigDomain')
    jest.spyOn(page, 'displayDomainAndDataType')
    jest.spyOn(page, 'removeSecretTimeout')
  })
  it('onLoad', () => {
    page.onLoad({})
    expect(page.handleConfigDomain).toBeCalled()
  })
  it('onShow', () => {
    page.onShow()
    expect(page.displayDomainAndDataType).toBeCalled()
  })
  it('onHide', () => {
    page.onHide()
    expect(page.removeSecretTimeout).toBeCalled()
  })
  it('onUnload', () => {
    page.onUnload()
  })
  afterEach(() => {
    jest.clearAllMocks()
  })
})

describe('secret page', () => {
  it('show action sheet', () => {
    jest.useFakeTimers()
    page.onSecretStart()
    page.onSecretStart()
    expect(wx.showActionSheet).not.toBeCalled()
    jest.advanceTimersByTime(3000)
    page.onSecretEnd()
    page.onSecretEnd()
    expect(wx.showActionSheet).toBeCalled()
  })
  it('not show action sheet', () => {
    jest.useFakeTimers()
    page.onSecretStart()
    page.onSecretStart()
    expect(wx.showActionSheet).not.toBeCalled()
    jest.advanceTimersByTime(2000)
    page.onSecretEnd()
    page.onSecretEnd()
    expect(wx.showActionSheet).not.toBeCalled()
  })
  afterEach(() => {
    jest.clearAllMocks()
  })
})

describe('open camera page', () => {
  it('navigate to camera page', () => {
    page.setData({ disableActionBtn: false })
    page.openCameraPage({ target: { id: 'camera' } })
    expect(wx.navigateTo).toBeCalled()
  })
  it('disable action botton', () => {
    page.setData({ disableActionBtn: true })
    page.openCameraPage({ target: { id: 'camera' } })
    expect(wx.navigateTo).not.toBeCalled()
  })
  afterEach(() => {
    jest.clearAllMocks()
  })
})
