// components/dataTable.js
Component({
  properties: {
    headers: {
      type: Array,
      value: []
    },
    rows: {
      type: Array, // [[row1_col1, row1_col2], [row2_col1, row2_col2], ...]
      value: []
    }
  },
  data: {
    html: ''
  },
  observers: {
    'rows, headers': function(rows, headers) {
      console.log(`[dataTable] headers=${JSON.stringify(headers)} rows=`, rows)
      this.setData({
        html: this._generateTable(rows, headers) || ''
      })
    }
  },
  methods: {
    _generateTable: function(rows = [], headers = []) {
      return `
        <table class="data-table">
          ${this._generateHeader(headers)}
          <tbody>
            ${this._generateRows(rows) ||
              `<tr>
                 <td class="body-cell no-data" colspan="${headers.length}">No data</td>
               </tr>`}
          </tbody>
        </table>
      `
    },
    _generateHeader: function(headers = []) {
      if (!headers.length) return ''

      const htmlHeaders = headers.map(header => `<th class="header-cell">${header}</th>`)
      return `
        <thead>
          ${htmlHeaders.join('')}
        </thead>`
    },
    _generateRows: function(rows = []) {
      const htmlRows = rows.map(row => {
        if (!row) {
          return `<tr></tr>`
        }
        const htmlColumns = row.map(
          col => `<td class="body-cell">${typeof col === 'object' ? JSON.stringify(col) : col}</td>`
        )
        return `<tr>${htmlColumns.join('')}</tr>`
      })
      return htmlRows.join('')
    }
  }
})
