Component({
  properties: {
    isShow: {
      type: Boolean,
      value: false
    },
    tableRows: {
      type: Array,
      value: []
    }
  },
  data: {
    html: ''
  },
  observers: {
    tableRows: function(tableRows) {
      console.log('[resultDebugModal] debugData:', tableRows)
      const html = this._generateTable(tableRows)
      this._setData({ html: html || '' })
    }
  },
  methods: {
    onHide: function() {
      this.triggerEvent('modalhide')
    },
    onCopyClick: function() {
      const csvString = this._tableRowsToCsvFormat(this.data.tableRows) || ''
      wx.setClipboardData({
        data: csvString
      })
      wx.showToast({
        title: 'Copied',
        duration: 1000
      })
    },
    _tableRowsToCsvFormat: function(tableRows = []) {
      const headers = ['Task', 'Time']
      const dataRows = tableRows.map(row => [row.task, row.time])
      const csvArray = [headers, ...dataRows]
      console.log('[_tableRowsToCsvFormat] csvArray:', csvArray)

      return csvArray.reduce((csvStr, rowArr) => {
        const rowStr = rowArr.join(',')
        return `${csvStr}${rowStr}\r\n`
      }, '')
    },
    _generateTable: function(data = []) {
      const rows = data.map(
        row => `
          <tr>
            <td class="debug-table-cell task">${row.task}</td>
            <td class="debug-table-cell">${row.time}</td>
          </tr>
        `
      )
      return `
        <table>
          <thead>
            <th>Task</th>
            <th>Time</th>
          </thead>
          <tbody>
            ${rows.join('')}
          </tbody>
        </table>
      `
    },
    _setData: function(obj = {}) {
      this.setData(obj)
    }
  }
})
