import logger from '../../pfEngine/utils/logger'
import { removeHtmlTag } from '../../pfEngine/utils/util'

Component({
  properties: {
    survey: {
      type: Object,
      value: {}
    }
  },
  data: {
    questionIndex: 0,
    questions: [],
    allOptions: [],
    isNextDisabled: true,
    results: {}
  },
  observers: {
    survey: function(survey) {
      this._setStatesBySurvey(survey)
    }
  },
  methods: {
    onOptionClick: function(e) {
      const { index } = e.currentTarget.dataset
      const option = this.data.allOptions[this.data.questionIndex][index]

      this._updateOption({
        questionIndex: this.data.questionIndex,
        optionIndex: index,
        checked: !option.checked
      })
    },
    onSwitchPage: function(e) {
      logger.log(`[onContinue]submitType=${e.detail.target.dataset.submitType}`)
      logger.log('[onContinue]value:', e.detail.value)
      this._updateResultsBySubmitValues(e.detail.value)

      if (e.detail.target.dataset.submitType === 'prev') {
        this._onPrevBtnClick()
        return
      }
      if (this.data.isNextDisabled) return

      e.detail.target.dataset.submitType === 'next' && this._onNextBtnClick()
      e.detail.target.dataset.submitType === 'done' && this._onDoneClick()
    },
    _setStatesBySurvey: function(survey = {}) {
      if (!survey.questions || !survey.questions.length) return

      this.setData({
        questions: survey.questions.map(question => ({
          ...question,
          title: removeHtmlTag(question.title),
          description: removeHtmlTag(question.description)
        })),
        allOptions: survey.questions.map(question => {
          return question.options.map(option => ({
            ...option,
            title: removeHtmlTag(option.title)
          }))
        }),
        isNextDisabled: survey.questions[0].isRequired
      })
    },
    _updateResultsBySubmitValues: function(values) {
      Object.entries(values).forEach(([questionId, optionIds]) => {
        if (!questionId || !optionIds) return

        this.setData({
          results: {
            ...this.data.results,
            [questionId]: Array.isArray(optionIds) ? optionIds : [optionIds]
          }
        })
      })
    },
    _onPrevBtnClick: function() {
      const prevQuestionIndex = this.data.questionIndex - 1
      if (prevQuestionIndex < 0) return

      this.setData({
        questionIndex: prevQuestionIndex,
        isNextDisabled: false
      })
    },
    _onNextBtnClick: function() {
      const newQuestionIndex = this.data.questionIndex + 1
      const checkedOptions = this.data.allOptions[newQuestionIndex]
      const isNextQuestionRequired = this.data.questions[newQuestionIndex].isRequired

      this.setData({
        questionIndex: newQuestionIndex,
        isNextDisabled: !this._isNextAllowed(
          this._countChecked(checkedOptions),
          isNextQuestionRequired ? 1 : 0
        )
      })
    },
    _onDoneClick: function() {
      logger.log('[surveyView][_onDoneClick]results:', this.data.results)
      this.setData({
        isNextDisabled: true
      })
      const eventDetail = { results: this.data.results }
      this.triggerEvent('surveySubmit', eventDetail)
    },
    _updateOption: function({ questionIndex, optionIndex, checked }) {
      const question = this.data.questions[questionIndex]
      const options = [...this.data.allOptions[questionIndex]]

      if (options[optionIndex].checked !== checked) {
        question.type === 'CheckBox'
          ? (options[optionIndex].checked = checked)
          : options.forEach((opt, i) => (opt.checked = i === optionIndex ? checked : false))
      }
      logger.log('[_updateOption]options:', options)

      const newAllOptions = JSON.parse(JSON.stringify(this.data.allOptions))
      newAllOptions[questionIndex] = options
      this.setData({
        allOptions: newAllOptions,
        isNextDisabled: !this._isNextAllowed(
          this._countChecked(options),
          question.isRequired ? 1 : 0
        )
      })
    },
    _isNextAllowed: function(checkedCount, minOptions) {
      if (isNaN(parseInt(minOptions))) {
        minOptions = this.data.questions[this.data.questionIndex].isRequired ? 1 : 0
      }
      return checkedCount >= minOptions
    },
    _countChecked: function(options) {
      let count = 0
      options.forEach(opt => opt.checked && count++)
      return count
    }
  }
})
