import status from '../../../pfEngine/utils/status.js'
import { OPEN_MODE, HANDAR_TYPE } from '../../../define'
const debug = require('../../../pfEngine/utils/debug')
const app = getApp()
const maxQueryCount = 20
const DEFAULT_RESULT_PAGE = `/pages/handAR/result/result`
let pfHandAR
let logger
let url

Page({
  data: {
    disableActionBtn: false,
    skus: [],
    initGuid: '',
    modes: Object.values(OPEN_MODE),
    currentMode: '',
    currentTypes: []
  },

  onLoad() {
    this.initValue()
  },

  initValue: function() {
    logger = app.globalData.logger
  },

  onReady() {
    this.initHandAR()
  },

  onShow() {
    if (app.globalData.backToWebView) {
      app.globalData.backToWebView = false
      this.onOpenCameraClick()
    }
  },

  onUnload() {
    pfHandAR?.unInit(statusCode => {
      if (statusCode === status.STATUS_FAIL) {
        wx.showToast({
          title: `unInit failed.`,
          icon: 'none',
          duration: 1000
        })
      }
    })
  },

  initHandAR: function() {
    try {
      this._initPfHandAR()
    } catch (err) {
      logger.error('error:', err)
    }
  },

  _initPfHandAR: function() {
    pfHandAR = require('../../../pfEngine/api/pfHandAR.js')
    pfHandAR
      .init({
        callback: this.initCallback
      })
      .then(r => logger.log(`${JSON.stringify(r)}`))
  },

  initCallback: async function(statusCode) {
    logger.log('pfHandAR initCallback status:' + statusCode)
    if (statusCode === status.STATUS_FAIL || statusCode === status.STATUS_WRONG_MODULE_VERSION) {
      this.setData({ disableActionBtn: true })
      wx.showModal({
        content: '初始化失败'
      })
    }
  },

  async updateProducts(types) {
    if (!types || types.length === 0) {
      this.setData({ disableActionBtn: true })
      this.updateListingUI([])
      return
    }
    wx.showLoading({ mask: true })
    let allProducts = []
    try {
      for (const type of types) {
        let products
        switch (type) {
          case HANDAR_TYPE.NAIL.type:
          case HANDAR_TYPE.NECKLACE.type:
            products = await this.loadProducts(type)
            break
          case HANDAR_TYPE.WATCH.type:
          case HANDAR_TYPE.BRACELET.type:
          case HANDAR_TYPE.RING.type:
            products = [...(await this.loadProducts(type)), ...(await this.loadSkuSets(type))]
            break
          case HANDAR_TYPE.NAILLOOK.type:
          case HANDAR_TYPE.JEWELRYLOOK.type:
            products = await this.loadLooks(type)
            break
          default:
            throw Error('载入产品失败')
        }
        allProducts = allProducts.concat(products)
      }
      if (allProducts.length === 0) {
        this.setData({ disableActionBtn: true })
        wx.showModal({
          content: `所选分类下查无产品，请确认后台有无资料！`
        })
        this.updateListingUI(allProducts)
      } else {
        this.updateListingUI(allProducts)
        this.setData({
          disableActionBtn: false,
          initGuid: this.data.skus[0].guid
        })
      }
    } catch (e) {
      wx.showModal({
        content: e.message || JSON.stringify(e)
      })
    }
    wx.hideLoading()
  },

  loadProducts(type) {
    return this.loadAllListByEffect(type).then(products => {
      const allProducts = products.flat()
      return this._parseProductList(allProducts)
    })
  },
  loadSkuSets(type) {
    return this.loadAllSkuSetByEffect(type).then(skuSets => {
      const allSkuSets = skuSets.flat()
      return this._parseSkuSetList(allSkuSets)
    })
  },
  loadLooks(type) {
    return this.loadAllLookByEffect(type).then(looks => {
      const allLooks = looks.flat()
      return this._parseLookList(allLooks)
    })
  },
  async loadAllItemsByEffect(type, fetchFunction) {
    let offset = 0
    let items = await fetchFunction(type, offset)
    try {
      while (items.length === offset + maxQueryCount) {
        offset += maxQueryCount
        const nextItems = await fetchFunction(type, offset)
        items = items.concat(nextItems)
      }
    } catch (error) {
      logger.error(`Error loading items for type ${type}:`, error)
    }
    return items
  },
  loadAllListByEffect(type) {
    return this.loadAllItemsByEffect(type, pfHandAR.getListByEffect)
  },
  loadAllSkuSetByEffect(type) {
    return this.loadAllItemsByEffect(type, pfHandAR.getSkuSetListByEffect)
  },
  loadAllLookByEffect(type) {
    return this.loadAllItemsByEffect(type, pfHandAR.getLooks)
  },

  updateListingUI(skus) {
    this.setData({
      skus: this._appendCheckboxInfo(skus)
    })
  },

  _parseProductList(products) {
    return products.flatMap(product => {
      const type = product.type
      const productThumb = product.thumbnailUrl
      return product.skus.map(sku => {
        sku.type = type
        sku.productThumb = productThumb
        sku.info = 'sku'
        return sku
      })
    })
  },

  _parseSkuSetList(skuSetList) {
    return skuSetList.map(skuSet => ({
      guid: skuSet.guid,
      name: skuSet.name,
      type: skuSet.type,
      info: 'skuSet',
      productThumb: skuSet.thumbnailUrl
    }))
  },

  _parseLookList(lookList) {
    return lookList.map(look => ({
      guid: look.guid,
      type: look.type,
      name: look.name,
      info: 'look',
      productThumb: look.thumbnailUrl
    }))
  },

  _appendCheckboxInfo(skus) {
    return skus.map(sku => ({
      ...sku,
      checked: false
    }))
  },

  onCheckboxChange(e) {
    const selectedCheckboxes = e.detail.value
    const updated = this.data.skus.map(sku => ({
      ...sku,
      checked: selectedCheckboxes.includes(sku.guid)
    }))
    this.setData({ skus: updated })
  },

  onModeChange(e) {
    const selectedMode = e.detail.value
    const mode = this.data.modes.find(item => item.mode === selectedMode)
    this.setData({
      currentMode: mode.mode,
      currentTypes: mode ? mode.types.map(type => ({ type, checked: false })) : [],
      skus: []
    })
  },

  onTypeChange: function(e) {
    const types = e.detail.value
    const updatedTypes = this.data.currentTypes.map(typeObj => ({
      ...typeObj,
      checked: types.includes(typeObj.type)
    }))
    this.setData({
      currentTypes: updatedTypes
    })
    this.updateProducts(types)
  },

  onSkuClick(e) {
    const { selectedSku } = e.currentTarget.dataset
    this.setData({
      initGuid: selectedSku.guid
    })
  },
  async onOpenCameraClick() {
    if (this.data.disableActionBtn) return
    try {
      url = await pfHandAR.getWebTryOnUrl(
        {
          skuGuids: this.data.skus
            .filter(sku => sku.info === 'sku')
            .filter(sku => sku.checked)
            .map(sku => sku.guid),
          lookGuids: this.data.skus
            .filter(sku => sku.info === 'look')
            .filter(sku => sku.checked)
            .map(sku => sku.guid),
          skuSetGuids: this.data.skus
            .filter(sku => sku.info === 'skuSet')
            .filter(sku => sku.checked)
            .map(sku => sku.guid)
        },
        this.data.initGuid,
        this.data.currentMode,
        {
          resultPage: debug.getEnableResultPage() ? DEFAULT_RESULT_PAGE : '',
          webEnv: {
            url: debug.getWebEnv()
          },
          debug: debug.getEnableHandARDebug()
        }
      )
      wx.navigateTo({
        url: `/pages/handAR/camera/camera?url=${encodeURIComponent(url)}`
      })
    } catch (e) {
      wx.showModal({
        content: `${e}`
      })
    }
  },

  onCopyClick() {
    if (url) {
      wx.setClipboardData({
        data: url,
        success: () => {
          wx.showToast({
            title: 'success'
          })
        }
      })
    } else {
      wx.showToast({
        icon: 'error',
        title: 'url is empty'
      })
    }
  }
})
