const logger = require('../../../pfEngine/utils/logger')
const debug = require('../../../pfEngine/utils/debug')
const version = require('../../../version')

Page({
  data: {
    webENV: 'PRODUCTION',
    appVersion: '',
    sdkVersion: '',
    filesSize: '',
    cachedFiles: '',
    enableWatch: false,
    enableBracelet: false,
    enableNail: false,
    enableRing: false,
    enableStacking: false,
    enableNecklace: false
  },

  onLoad: function(options) {
    const license = debug.getLicense()
    this.updateVersionInfo()
    this.setData({
      ...debug.getSetting(),
      enableLicense: license.enable ?? false,
      enableWatch: license.watch ?? false,
      enableBracelet: license.bracelet ?? false,
      enableNail: license.nail ?? false,
      enableRing: license.ring ?? false,
      enableStacking: license.stacking ?? false,
      enableNecklace: license.necklace ?? false
    })
  },

  updateVersionInfo: function() {
    let sdkVersion = ''
    const appVersion = version.tag
    try {
      const handAR = require('../../../pfEngine/loadModule/HandAR')
      sdkVersion = handAR._getVersion()
    } catch (e) {
      logger.warn(`pages/secretPage updateVersionInfo: ${e}`)
    }
    this.setData({
      sdkVersion,
      appVersion
    })
  },

  onShareAppMessage: function() {},
  onEnableResultPageChanged(e) {
    debug.setEnableResultPage(e.detail.value)
    this.popupWarningMessageIfNeed('请重启App以切換enable result page')
  },
  onEnableHandARDebugChanged(e) {
    debug.setEnableHandARDebug(e.detail.value)
    this.popupWarningMessageIfNeed('请重启App以切換enable HandAR debug')
  },
  webEnvChange(e) {
    this.setData({
      webENV: e.detail.value
    })
    debug.setWebEnv(e.detail.value)
    this.popupWarningMessageIfNeed('请重启App以切換Web env')
  },
  popupWarningMessageIfNeed(msg) {
    wx.showToast({
      title: msg,
      icon: 'none',
      duration: 3000
    })
  },
  onLicenseSettingChanged(e) {
    this.setData({
      enableLicense: e.detail.value
    })
    debug.setLicense('enable', e.detail.value)
  },
  onWatchLicenseChanged(e) {
    this.setData({
      enableWatch: e.detail.value
    })
    debug.setLicense('watch', e.detail.value)
  },
  onBraceletLicenseChanged(e) {
    this.setData({
      enableBracelet: e.detail.value
    })
    debug.setLicense('bracelet', e.detail.value)
  },
  onNailLicenseChanged(e) {
    this.setData({
      enableNail: e.detail.value
    })
    debug.setLicense('nail', e.detail.value)
  },
  onRingLicenseChanged(e) {
    this.setData({
      enableRing: e.detail.value
    })
    debug.setLicense('ring', e.detail.value)
  },
  onStackingLicenseChanged(e) {
    this.setData({
      enableStacking: e.detail.value
    })
    debug.setLicense('stacking', e.detail.value)
  },
  onNecklaceLicenseChanged(e) {
    this.setData({
      enableNecklace: e.detail.value
    })
    debug.setLicense('necklace', e.detail.value)
  }
})
