// pages/secretPage.js
import logger from '../../pfEngine/utils/logger'
import debug from '../../pfEngine/utils/debug'
import util from '../../pfEngine/utils/util'
import version from '../../version'

const app = getApp()
Page({
  data: {
    saveLogToStorage: false,
    logLevel: 1,
    enablePreviewMode: false,
    services: [
      { name: 'faceAttribute', checked: false },
      { name: 'makeup', checked: false },
      { name: 'handAR', checked: false },
      { name: 'shadeFinder', checked: false },
      { name: 'skincare', checked: false },
      { name: 'tutorial', checked: false }
    ],
    productMappingList: [],
    domain: 0,
    appVersion: '',
    sdkVersion: '',
    useDebugConfig: false,
    SDKSetting: 0
  },
  onLoad: function() {
    const appParam = util.getAppParam()
    this.updateVersionInfo()
    this.setData({
      logLevel: logger.getLogLevel(),
      saveLogToStorage: logger.isEnableSaveLogToStorage(),
      enablePreviewMode: appParam.dataType === 'preview',
      domain: !appParam.domain || appParam.domain === 'china' ? 0 : 1,
      ...debug.getSetting()
    })
    const services = this.data.services.map(item => {
      item.checked = this.data.productMappingList.includes(item.name)
      return item
    })
    this.setData({
      services
    })
  },

  updateVersionInfo: function() {
    let sdkVersion = ''
    const appVersion = version.tag
    try {
      const common = require('../../pfEngine/loadCommon/PerfectLib')
      sdkVersion = common._getVersion()
    } catch (e) {
      logger.warn(`pages/secretPage updateVersionInfo: ${e.message}`)
    }
    this.setData({
      sdkVersion,
      appVersion
    })
  },
  logLevelChange: function(e) {
    logger.setLogLevel(parseInt(e.detail.value))
  },
  onSaveLogToStorageChanged(e) {
    this.setData({
      saveLogToStorage: e.detail.value
    })
    logger.enableSaveLogToStorage(e.detail.value)
  },

  onEnablePreviewModeChanged(e) {
    app.globalData.dataType = e.detail.value ? 'preview' : 'production'
    util.setAppParam({ dataType: app.globalData.dataType })
    this.popupWarningMessageIfNeed('请重启App以切換Server')
  },
  onProductMappingChanged(e) {
    this.setData({
      productMappingList: e.detail.value
    })
    debug.setProductMappingList(e.detail.value)
    this.popupWarningMessageIfNeed('请重启App以抓取mapping资料')
  },
  domainChange(e) {
    app.globalData.domain = parseInt(e.detail.value) === 0 ? 'china' : 'nonchina'
    util.setAppParam({ domain: app.globalData.domain })
    this.popupWarningMessageIfNeed('请重启App以切換Server')
  },
  popupWarningMessageIfNeed(msg) {
    const isCommonLoaded = app.isCommonLoaded()
    if (isCommonLoaded) {
      wx.showToast({
        title: msg,
        icon: 'none',
        duration: 3000
      })
      app.globalData.domain = 'please restart app'
      app.globalData.dataType = 'please restart app'
    }
  },
  onUseDebugConfigChanged(e) {
    this.setData({
      useDebugConfig: e.detail.value
    })
    debug.setUseDebugConfig(e.detail.value)
  },
  SDKSettingChange(e) {
    this.setData({
      SDKSetting: parseInt(e.detail.value)
    })
    debug.setSDKSetting(parseInt(e.detail.value))
    this.popupWarningMessageIfNeed('请重启App以切換Config')
  }
})
