# Makeup-ShadeFinder SDK integration guide

This document lists step for integrating Makeup and ShadeFinder libraries. For using `Makeup` and `ShadeFinder`, please read README.md in `Makeup SDK` and `ShadeFinder SDK`.

## Prerequisite

- ShadeFinder SDK v1.1 or higher

- Makeup SDK v1.11 or higher

## Steps

> ⚠️ All steps are based on the folder structure in SDK libraries, please keep an eye on the path of libraries and files if folder structure were customized.

1. Unzip `ShandeFinder`,`Makeup`  SDK and get 2 folders that contain `Doc`, `SampleProject` and `Libraries`.

1. Create a blank WeChat miniprogram project

1. Integrate Makeup and ShadeFinder libraries

    1. Copy `pfEngnie` from `Makeup/Libraries`, paste it to project root.
    1. Rename `Makeup.js` to `sfMakeup.js` from `pfEnigne/loadModule` of `ShadeFinder/Libraries`, copy it to `Project/pfEngine`.
    1. Rename `pfMakeup.js` to `pfSfMakeup.js` in `pfEngine/api` of `ShadeFinder/Libraries`, copy `pfSfMakeup.js`, `pfShadeFinder.js` to `Project/pfEngine/api`.
    1. Copy `ShadeFinder.js` from `pfEnigne/loadModule` of `ShadeFinder/Libraries` to `Project/pfEngine/loadModule`.
    1. Create a new Folder named `makeup` in `pfEngine`, move `loadAndroidEngine` and `loadIOSMkEngine` into it.
    1. Create a new Folder named `shadeFinder` in `pfEngine`, move `loadIOSSfEngine` and `loadAndroidEngine` from `pfEnigne` of `ShadeFinder/Libraries` into it.

1. Modify reference paths

    1. Modify the path of require libraries in `Project/pfEngine/api/pfShadeFinder.js` because folder structure changed.

       ```javascript
       // const venus =
       //    platform === `ios`
       //      ? require('../loadIOSSfEngine/Venus')
       //      : require('../loadAndroidEngine/Venus')
       const venus =
         platform === `ios`
           ? require('../shadeFinder/loadIOSSfEngine/Venus')
           : require('../shadeFinder/loadAndroidEngine/Venus')
       _getShadeFinder().init({
         // Omit other parameters
         // wasmPath: '/pfEngine/loadAndroidEngine/ShadeFinder.wasm'
         wasmPath: '/pfEngine/shadeFinder/loadAndroidEngine/ShadeFinder.wasm'
       })
       ```

    2. Modify the path of required libraries in `Project/pfEngine/api/pfSfMakeup.js`.

       ```javascript
       // const venus =
       //    platform === `ios`
       //      ? require('../loadIOSSfEngine/Venus')
       //      : require('../loadAndroidEngine/Venus')
       const venus =
          platform === `ios`
            ? require('../shadeFinder/loadIOSSfEngine/Venus')
            : require('../shadeFinder/loadAndroidEngine/Venus')
       ```

    3. Modify the path of required libraries in `Project/pfEngine/api/pfMakeup.js`.
  
       ```javascript
       // const venus =
       //    platform === `ios`
       //      ? require('../loadIOSSfEngine/Venus')
       //      : require('../loadAndroidEngine/Venus')
       const venus =
          platform === `ios`
            ? require('../makeup/loadIOSSfEngine/Venus')
            : require('../makeup/loadAndroidEngine/Venus')
       _getMakeup().init({
          // Omit other parameters
          // wasmPath: '/pfEngine/loadAndroidEngine/Makeup.wasm'
          wasmPath: '/pfEngine/makeup/loadAndroidEngine/Makeup.wasm'
       })
       ```

1. Use Makeup and ShadeFinder in WeChat miniprogram

    1. Modify `subPackages` in `app.json` as below:

        ```javascript
        "subPackages": [
            {
                "root": "pfEngine/makeup/loadAndroidEngine",
                "pages": [
                    "loadpkg"
                ]
            },
            {
                "root": "pfEngine/makeup/loadIOSMkEngine",
                "pages": [
                    "loadpkg"
                ]
            },
            {
                "root": "pfEngine/loadModule",
                "pages": [
                    "page/loadpkg"
                ],
                "plugins": {
                    "tfjsPlugin": {
                    "version": "0.0.9",
                    "provider": "wx6afed118d9e81df9"
                    }
                }
            },
            {
                "root": "pfEngine/shadeFinder/loadAndroidEngine",
                "pages": [
                    "loadpkg"
                ]
            },
            {
                "root": "pfEngine/shadeFinder/loadIOSSfEngine",
                "pages": [
                    "loadpkg"
                ]
            }
        ]
        ```

    1. Load sub-package before using Makeup or ShadeFinder functions

       ```javascript
       // example for using shadeFinder
       openCameraPage: function(e) {
          const cameraPage = '/pages/shadeFinder/camera/camera'
          const isPackageLoaded = app.isPackageLoaded(
            systemInfo.platform === 'ios'
            ? '/pfEngine/loadIOSSfEngine/Venus'
            : '/pfEngine/loadAndroidEngine/Venus'
          )
          wx.navigateTo({
             url: isPackageLoaded
             ? cameraPage
             : systemInfo.platform === 'ios'
             ? `/pfEngine/shadeFinder/loadIOSSfEngine/loadpkg?cameraPage=${cameraPage}`
             : `/pfEngine/shadeFinder/loadAndroidEngine/loadpkg?cameraPage=${cameraPage}`
          })
       }
       ```

       ```javascript
       // example for using makeup
       openCameraPage: function(e) {
         app.globalData.defaultPhotoMode = e.target.id === 'photo'
         const isPackageLoaded = app.isPackageLoaded(platform === 'ios' ? '/pfEngine/loadIOSMkEngine/Venus' : '/pfEngine/loadAndroidEngine/Venus')
         const cameraPage = '/pages/camera/camera'
         wx.navigateTo({
           url: isPackageLoaded
           ? cameraPage
           : platform === 'ios'
           ? `/pfEngine/makeup/loadIOSMkEngine/loadpkg?cameraPage=${cameraPage}`
           : `/pfEngine/makeup/loadAndroidEngine/loadpkg?cameraPage=${cameraPage}`
         })
       }
       ```
