import { getValue, setValue } from './util'
import supportType from '../../pfEngine/utils/supportType'
const CACHE_KEY_DEBUGGER_SETTING = 'CACHE_KEY_DEBUGGER_SETTING'
let setting = {
  showAlignDot: false,
  showBrushPoint: false,
  testCache: false,
  initialSupportType: {
    [supportType.MAKEUP.key]: true,
    [supportType.HAIR.key]: true,
    [supportType.EARRING.key]: true
  },
  productMappingList: ['faceAttribute', 'makeup', 'handAR', 'shadeFinder', 'skincare', 'tutorial'],
  deleteProductGuid: false,
  SDKSetting: 0,
  webENV: 'PRODUCTION',
  enableResultPage: true,
  enableHandARDebug: false,
  useDebugConfig: false
}

const loadSettingFromStorage = () => {
  const storedSetting = getValue(CACHE_KEY_DEBUGGER_SETTING, '')
  if (storedSetting) {
    setting = {
      ...setting,
      ...storedSetting.setting
    }
  } else {
    saveSettingToStorage()
  }
}
const saveSettingToStorage = () => {
  setValue(CACHE_KEY_DEBUGGER_SETTING, { setting })
}
const getSetting = () => {
  return setting
}
const getEnableLogEffectFPS = () => {
  return setting.enableLogEffectFPS
}
const setEnableLogEffectFPS = enable => {
  setting.enableLogEffectFPS = enable
  saveSettingToStorage()
}
const getShowAlignDot = () => {
  return setting.showAlignDot
}
const setShowAlignDot = isShow => {
  setting.showAlignDot = isShow
  saveSettingToStorage()
}
const getShowBrushPoint = () => setting.showBrushPoint
const setShowBrushPoint = isShow => {
  setting.showBrushPoint = isShow
  saveSettingToStorage()
}
const getDisable2dStrokes = () => setting.disable2dStrokes
const setDisable2dStrokes = disable => {
  setting.disable2dStrokes = disable
  saveSettingToStorage()
}
const getDisableDesc = () => setting.disableDesc
const setDisableDesc = disable => {
  setting.disableDesc = disable
  saveSettingToStorage()
}
const getTestCache = () => setting.testCache
const setTestCache = test => {
  setting.testCache = test
  saveSettingToStorage()
}
const getInitialSupportType = () => {
  return setting.initialSupportType
}
const setInitialSupportType = (feature, isEnable) => {
  setting.initialSupportType[feature] = isEnable
  saveSettingToStorage()
}
function setSamplePhoto(obj) {
  setting.mtSamplePhoto = obj
  saveSettingToStorage()
}
function setIsLabTesting(isLabTesting) {
  setting.enableLabTesting = isLabTesting
  saveSettingToStorage()
}
function getIsLabTesting() {
  return setting.enableLabTesting
}
function setIsPFColorLabTesting(isPFColorLabTesting) {
  setting.enablePFColorLabTesting = isPFColorLabTesting
  saveSettingToStorage()
}
function getIsPFColorLabTesting() {
  return setting.enablePFColorLabTesting
}
function getLabValue() {
  return setting.labValue
}
function setLabValue(labID, labValue) {
  if (!setting.labValue) {
    setting.labValue = { L: 0, a: 0, b: 0 }
  }
  switch (labID) {
    case 'L':
      setting.labValue.L = labValue
      break
    case 'a':
      setting.labValue.a = labValue
      break
    case 'b':
      setting.labValue.b = labValue
      break
  }
  saveSettingToStorage()
}
function getPFColorLabValue() {
  return setting.pfColorLabValue
}
function setPFColorLabValue(labID, labValue) {
  if (!setting.pfColorLabValue) {
    setting.pfColorLabValue = { L: 0, a: 0, b: 0 }
  }
  switch (labID) {
    case 'L':
      setting.pfColorLabValue.L = labValue
      break
    case 'a':
      setting.pfColorLabValue.a = labValue
      break
    case 'b':
      setting.pfColorLabValue.b = labValue
      break
  }
  saveSettingToStorage()
}

function getSamplePhoto() {
  return setting.mtSamplePhoto
}
function setIsSaveDetectionImage(isSaveDetectionImage) {
  setting.saveDetectionImage = isSaveDetectionImage
  saveSettingToStorage()
}
function getIsSaveDetectionImage() {
  return setting.saveDetectionImage
}
function setPrintSkuLabInfo(isPrintSkuLabInfo) {
  setting.enablePrintSkuLabInfo = isPrintSkuLabInfo
  saveSettingToStorage()
}
function getPrintSkuLabInfo() {
  return setting.enablePrintSkuLabInfo
}
function setUnderTone(value) {
  setting.underTone = value
  saveSettingToStorage()
}
function getUnderTone() {
  return setting.underTone
}
function setProductMappingList(productMappingList) {
  setting.productMappingList = productMappingList
  saveSettingToStorage()
}
function getProductMappingList() {
  return setting.productMappingList
}
function setProductID(string) {
  setting.productIDInput = string
  saveSettingToStorage()
}
function getProductID() {
  return setting.productIDInput
}
function setDetectMode(detectMode) {
  setting.detectMode = detectMode
  saveSettingToStorage()
}
function getDetectMode() {
  return setting.detectMode
}
function setShowFpsInfo(showFpsInfo) {
  setting.showFpsInfo = showFpsInfo
  saveSettingToStorage()
}
function getShowFpsInfo() {
  return setting.showFpsInfo
}
function setDeleteProductGuid(deleteProductGuid) {
  setting.deleteProductGuid = deleteProductGuid
  saveSettingToStorage()
}

function getDeleteProductGuid() {
  return setting.deleteProductGuid
}

const getSDKSetting = () => setting.SDKSetting
const setSDKSetting = value => {
  setting.SDKSetting = value
  saveSettingToStorage()
}

const getLicense = () => {
  try {
    const licenseSetting = require('./licenseSetting').default
    return licenseSetting.getLicense()
  } catch (e) {
    return {}
  }
}

const setLicense = (key, value) => {
  try {
    const licenseSetting = require('./licenseSetting').default
    licenseSetting.setLicense(key, value)
  } catch {}
}

const getGTInput = () => setting.GTInput
const setGTInput = obj => {
  setting.GTInput = obj
  saveSettingToStorage()
}

const getWebEnv = () => setting.webENV
const setWebEnv = value => {
  setting.webENV = value
  saveSettingToStorage()
}

const getEnableResultPage = () => setting.enableResultPage
const setEnableResultPage = enable => {
  setting.enableResultPage = enable
  saveSettingToStorage()
}

const getEnableHandARDebug = () => setting.enableDebugFps
const setEnableHandARDebug = enable => {
  setting.enableDebugFps = enable
  saveSettingToStorage()
}

const getUseDebugConfig = () => setting.useDebugConfig
const setUseDebugConfig = enable => {
  setting.useDebugConfig = enable
  saveSettingToStorage()
}

module.exports = {
  loadSettingFromStorage,
  getSetting,
  getShowAlignDot,
  setShowAlignDot,
  getShowBrushPoint,
  setShowBrushPoint,
  getInitialSupportType,
  setInitialSupportType,
  setSamplePhoto,
  getSamplePhoto,
  setIsLabTesting,
  getIsLabTesting,
  setLabValue,
  getLabValue,
  setIsSaveDetectionImage,
  getIsSaveDetectionImage,
  setPrintSkuLabInfo,
  getPrintSkuLabInfo,
  setUnderTone,
  getUnderTone,
  setProductMappingList,
  getProductMappingList,
  setProductID,
  getProductID,
  setDetectMode,
  getDetectMode,
  setShowFpsInfo,
  getShowFpsInfo,
  getSDKSetting,
  setSDKSetting,
  setDeleteProductGuid,
  getDeleteProductGuid,
  getGTInput,
  setGTInput,
  setDisable2dStrokes,
  getDisable2dStrokes,
  setDisableDesc,
  getDisableDesc,
  setTestCache,
  getTestCache,
  setEnableLogEffectFPS,
  getEnableLogEffectFPS,
  getWebEnv,
  setWebEnv,
  getEnableResultPage,
  setEnableResultPage,
  getEnableHandARDebug,
  setEnableHandARDebug,
  getLicense,
  setLicense,
  getUseDebugConfig,
  setUseDebugConfig,
  getPFColorLabValue,
  setPFColorLabValue,
  setIsPFColorLabTesting,
  getIsPFColorLabTesting
}
