const logger = wx.canIUse('getRealtimeLogManager') ? wx.getRealtimeLogManager() : wx.getLogManager()
const PREFIX = '[pf]'

const CACHE_KEY_DEBUG_SETTING = 'CACHE_KEY_DEBUG_SETTING'
const CACHE_KEY_LOG_HISTORY = 'CACHE_KEY_LOG_HISTORY'

let debugSetting = {
  saveLogToStorage: false,
  logLevel: 1
}
let logHistory = ''
const init = () => {
  const setting = wx.getStorageSync(CACHE_KEY_DEBUG_SETTING)
  if (setting && setting.setting) debugSetting = setting.setting
  const history = wx.getStorageSync(CACHE_KEY_LOG_HISTORY)
  if (history && history.log) {
    logHistory = history.log
  }
  console.log('logger has been inited!', JSON.stringify(debugSetting))
}
function enableSaveLogToStorage(isEnable) {
  debugSetting.saveLogToStorage = isEnable
  setDebugSetting()
}
function clearLogHistory() {
  logHistory = ''
  wx.setStorage({
    key: CACHE_KEY_LOG_HISTORY,
    data: { log: '' }
  })
}
function log() {
  if (debugSetting.logLevel === 3) {
    const args = Array.from(arguments)
    storeLog('[LOG]', ...args)
    logger && logger.info(...args)
    args.unshift(getNow())
    args.unshift(PREFIX)
    console.log(...args)
  }
}

function warn() {
  if (debugSetting.logLevel >= 2) {
    const args = Array.from(arguments)
    storeLog('[WARN]', ...args)
    logger && logger.warn(...args)
    args.unshift(getNow())
    args.unshift(PREFIX)
    console.warn(...args)
  }
}

function error() {
  if (debugSetting.logLevel >= 1) {
    const args = Array.from(arguments)
    storeLog('[ERROR]', ...args)
    logger && logger.error(...args)
    args.unshift(getNow())
    args.unshift(PREFIX)
    console.error(...args)
  }
}
function storeLog() {
  if (debugSetting.logLevel === 0) {
    return ''
  }
  const args = Array.from(arguments)
  args.splice(1, 0, getNow())
  logHistory =
    logHistory + '\n' + args.reduce((sum, i) => (sum += ` ${JSON.stringify(i)}`)).replace(/"/g, '')
  if (debugSetting.saveLogToStorage) {
    wx.setStorage({
      key: CACHE_KEY_LOG_HISTORY,
      data: { log: logHistory },
      fail: function() {
        wx.showToast({
          title: 'log to storage error! try to clear log'
        })
        clearLogHistory()
      }
    })
  }

  return logHistory
}
function getLogHistory() {
  return logHistory
}
function copyLogToClipboard() {
  wx.setClipboardData({
    data: logHistory
  })
  wx.showToast({
    title: 'Copied',
    duration: 1000
  })
}
function getNow() {
  const d = new Date()
  const h = addZero(d.getHours(), 2)
  const m = addZero(d.getMinutes(), 2)
  const s = addZero(d.getSeconds(), 2)
  const ms = addZero(d.getMilliseconds(), 3)
  return '[' + h + ':' + m + ':' + s + ':' + ms + ']'
}
function setDebugSetting() {
  wx.setStorage({
    key: CACHE_KEY_DEBUG_SETTING,
    data: { setting: debugSetting }
  })
}
function setLogLevel(logLevel) {
  debugSetting.logLevel = logLevel
  setDebugSetting()
}

function isEnableSaveLogToStorage() {
  return debugSetting.saveLogToStorage
}
function getLogLevel() {
  return debugSetting.logLevel
}
function addZero(x, n) {
  while (x.toString().length < n) {
    x = '0' + x
  }
  return x
}
module.exports = {
  init,
  log,
  warn,
  error,
  enableSaveLogToStorage,
  isEnableSaveLogToStorage,
  getLogLevel,
  clearLogHistory,
  getLogHistory,
  copyLogToClipboard,
  setLogLevel
}
